pub fn scan_execution_log(
store: &dyn EventStore,
run_id: &RunId,
from: Seq,
) -> Result<Vec<ExecutionLog>, KernelError>Expand description
Scans the event store for the run and returns the canonical execution log (state_hash None).
pub fn scan_execution_log(
store: &dyn EventStore,
run_id: &RunId,
from: Seq,
) -> Result<Vec<ExecutionLog>, KernelError>Scans the event store for the run and returns the canonical execution log (state_hash None).