pub fn scan_execution_trace(
store: &dyn EventStore,
run_id: &RunId,
from: Seq,
) -> Result<Vec<KernelTraceEvent>, KernelError>Expand description
Scans the event store and returns the unified kernel trace event view.
pub fn scan_execution_trace(
store: &dyn EventStore,
run_id: &RunId,
from: Seq,
) -> Result<Vec<KernelTraceEvent>, KernelError>Scans the event store and returns the unified kernel trace event view.