Run identity types for the Oris kernel.
RunId identifies a long-running run; StepId identifies a step (e.g. node + attempt); Seq is the monotonically increasing event sequence number per run.
Run identity types for the Oris kernel.
RunId identifies a long-running run; StepId identifies a step (e.g. node + attempt); Seq is the monotonically increasing event sequence number per run.