Module runner

Module runner 

KernelRunner: recommended way to run the kernel from sync or async code.

Encapsulates the correct Tokio runtime usage so callers do not need to use rt.enter(), block_in_place, or spawn_blocking manually. Use this instead of calling kernel.run_until_blocked directly when using GraphStepFnAdapter or other step functions that require a runtime.

Structs

KernelRunner
Runner that executes the kernel with correct runtime handling.