run_timeline

Function run_timeline 

pub fn run_timeline(
    events: &dyn EventStore,
    run_id: &RunId,
) -> Result<RunTimeline, KernelError>
Build a RunTimeline from an event store by scanning all events for the run and deriving final status from the last event(s).