pub struct TimelineFork {
pub source_run_id: RunId,
pub branch_id: RunId,
pub fork_point_seq: Seq,
pub alternate_event: Option<Event>,
}Expand description
A timeline fork: represents a forked execution from a checkpoint.
Fields
source_run_id: RunIdOriginal run that was forked.
branch_id: RunIdNew branch (forked) run id.
fork_point_seq: SeqSequence number of the fork point (events up to and including this seq were replayed).
alternate_event: Option<Event>The alternate event injected at the fork point (if any).