pub fn run_timeline(
events: &dyn EventStore,
run_id: &RunId,
) -> Result<RunTimeline, KernelError>Expand description
Build a RunTimeline from an event store by scanning all events for the run and deriving final status from the last event(s).